@@ -4,8 +4,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2003-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header file
@@ -22,16 +22,9 @@
 #include "model_utils.h"
 
 // kde includes
-#if QT_VERSION < 0x050000
+#include <klocale.h>
 #include <kinputdialog.h>
-#endif
-#include <KLocalizedString>
-#include <KMessageBox>
-
-// qt includes
-#if QT_VERSION >= 0x050000
-#include <QInputDialog>
-#endif
+#include <kmessagebox.h>
 
 using namespace Uml;
 
@@ -80,18 +73,18 @@ UMLObject* UMLPackage::clone() const
  * Adds an existing association to the matching concept in the list of concepts.
  * The selection of the matching concept depends on the association type:
  * For generalizations, the assoc is added to the concept that matches role A.
- * For aggregations and compositions, the assoc is added to the concept
+ * For aggregations and compositions , the assoc is added to the concept
  * that matches role B.
  * @param assoc   the association to add
  */
 void UMLPackage::addAssocToConcepts(UMLAssociation* assoc)
 {
-    if (! AssociationType::hasUMLRepresentation(assoc->getAssocType()))
+    if (! AssociationType::hasUMLRepresentation(assoc->getAssocType()) )
         return;
     Uml::ID::Type AId = assoc->getObjectId(Uml::RoleType::A);
     Uml::ID::Type BId = assoc->getObjectId(Uml::RoleType::B);
     UMLObject *o = NULL;
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         o = oit.next();
         UMLCanvasObject *c = dynamic_cast<UMLCanvasObject*>(o);
         if (c == NULL)
@@ -115,7 +108,7 @@ void UMLPackage::addAssocToConcepts(UMLAssociation* assoc)
 void UMLPackage::removeAssocFromConcepts(UMLAssociation *assoc)
 {
     UMLObject *o = 0;
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         o = oit.next();
         UMLCanvasObject *c = dynamic_cast<UMLCanvasObject*>(o);
         if (c) {
@@ -166,21 +159,13 @@ bool UMLPackage::addObject(UMLObject *pObject)
     else {
       QString name = pObject->name();
       QString oldName = name;
-      while (findObject(name) != NULL) {
+      while ( findObject( name ) != NULL  ) {
          QString prevName = name;
-         name = Model_Utils::uniqObjectName(pObject->baseType(), this);
+         name = Model_Utils::uniqObjectName(pObject->baseType(),this);
          bool ok = true;
-#if QT_VERSION >= 0x050000
-         name = QInputDialog::getText((QWidget*)UMLApp::app(),
-                                      i18nc("object name", "Name"),
-                                      i18n("An object with the name %1\nalready exists in the package %2.\nPlease enter a new name:", prevName, this->name()),
-                                      QLineEdit::Normal,
-                                      name, &ok);
-#else
          name = KInputDialog::getText(i18nc("object name", "Name"),
                                       i18n("An object with the name %1\nalready exists in the package %2.\nPlease enter a new name:", prevName, this->name()),
                                       name, &ok, (QWidget*)UMLApp::app());
-#endif
          if (!ok) {
             name = oldName;
             continue;
@@ -191,11 +176,11 @@ bool UMLPackage::addObject(UMLObject *pObject)
             continue;
         }
       }
-      if (oldName != name) {
+      if ( oldName != name ) {
         pObject->setName(name);
       }
     }
-    m_objects.append(pObject);
+    m_objects.append( pObject );
     return true;
 }
 
@@ -228,12 +213,14 @@ void UMLPackage::removeAllObjects()
     UMLCanvasObject::removeAllChildObjects();
     UMLObject *o = NULL;
 
-    while (!m_objects.isEmpty() && (o = m_objects.first()) != NULL)  {
+    while ( !m_objects.isEmpty() && (o = m_objects.first()) != NULL )  {
         UMLPackage *pkg = dynamic_cast<UMLPackage*>(o);
         if (pkg)
             pkg->removeAllObjects();
         removeObject(o);
-        delete o;
+        //delete o;
+        // CHECK: Direct usage of the destructor crashes on associations.
+        o->deleteLater();
     }
 }
 
@@ -254,10 +241,8 @@ UMLObjectList UMLPackage::containedObjects()
 UMLObject * UMLPackage::findObject(const QString &name)
 {
     const bool caseSensitive = UMLApp::app()->activeLanguageIsCaseSensitive();
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         UMLObject *obj = oit.next();
-        if (!obj)
-            continue;
         if (caseSensitive) {
             if (obj->name() == name)
                 return obj;
@@ -280,21 +265,20 @@ UMLObject * UMLPackage::findObjectById(Uml::ID::Type id)
 }
 
 /**
- * Append all packages from this package (and those from nested packages)
+ * Append all packages from this packaed ( and those from nested packeges)
  * to the given UMLPackageList.
  *
  * @param packages        The list to append to
  * @param includeNested   Whether to include the packages from nested packages
  *                        (default:true)
  */
-void UMLPackage::appendPackages(UMLPackageList& packages, bool includeNested)
+void UMLPackage::appendPackages(UMLPackageList& packages, bool includeNested )
 {
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         UMLObject *o = oit.next();
-        uIgnoreZeroPointer(o);
         ObjectType ot = o->baseType();
-        if (ot == ot_Package || ot == ot_Folder) {
-            packages.append(static_cast<UMLPackage*>(o));
+        if (ot == ot_Package) {
+            packages.append((UMLPackage *)o);
             if (includeNested) {
                UMLPackage *inner = static_cast<UMLPackage*>(o);
                inner->appendPackages(packages);
@@ -314,9 +298,8 @@ void UMLPackage::appendPackages(UMLPackageList& packages, bool includeNested)
 void UMLPackage::appendClassifiers(UMLClassifierList& classifiers,
                                    bool includeNested /* = true */)
 {
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         UMLObject *o = oit.next();
-        uIgnoreZeroPointer(o);
         ObjectType ot = o->baseType();
         if (ot == ot_Class || ot == ot_Interface ||
                 ot == ot_Datatype || ot == ot_Enum || ot == ot_Entity) {
@@ -328,6 +311,30 @@ void UMLPackage::appendClassifiers(UMLClassifierList& classifiers,
     }
 }
 
+/**
+ * Append all classes from this package (and those from
+ * nested packages) to the given UMLClassifierList.
+ *
+ * @param classes         The list to append to.
+ * @param includeNested   Whether to include the classes from
+ *                        nested packages (default: true.)
+ */
+void UMLPackage::appendClasses(UMLClassifierList& classes,
+                               bool includeNested /* = true */)
+{
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
+        UMLObject *o = oit.next();
+        ObjectType ot = o->baseType();
+        if (ot == ot_Class) {
+            UMLClassifier *c = static_cast<UMLClassifier*>(o);
+            classes.append(c);
+        } else if (includeNested && (ot == ot_Package || ot == ot_Folder)) {
+            UMLPackage *inner = static_cast<UMLPackage *>(o);
+            inner->appendClasses(classes);
+        }
+    }
+}
+
 /**
  * Append all entities from this package (and those
  * from nested packages) to the given UMLEntityList.
@@ -336,12 +343,11 @@ void UMLPackage::appendClassifiers(UMLClassifierList& classifiers,
  * @param includeNested   Whether to include the entities from
  *                        nested packages (default: true.)
  */
-void UMLPackage::appendEntities(UMLEntityList& entities,
-                                 bool includeNested /* = true */)
+void UMLPackage::appendEntities( UMLEntityList& entities,
+                                 bool includeNested /* = true */ )
 {
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         UMLObject *o = oit.next();
-        uIgnoreZeroPointer(o);
         ObjectType ot = o->baseType();
         if (ot == ot_Entity) {
             UMLEntity *c = static_cast<UMLEntity*>(o);
@@ -364,9 +370,8 @@ void UMLPackage::appendEntities(UMLEntityList& entities,
 void UMLPackage::appendClassesAndInterfaces(UMLClassifierList& classifiers,
         bool includeNested /* = true */)
 {
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         UMLObject *o = oit.next();
-        uIgnoreZeroPointer(o);
         ObjectType ot = o->baseType();
         if (ot == ot_Class || ot == ot_Interface) {
             UMLClassifier *c = static_cast<UMLClassifier*>(o);
@@ -378,6 +383,30 @@ void UMLPackage::appendClassesAndInterfaces(UMLClassifierList& classifiers,
     }
 }
 
+/**
+ * Append all interfaces from this package (and those from
+ * nested packages) to the given UMLClassifierList.
+ *
+ * @param interfaces      The list to append to.
+ * @param includeNested   Whether to include the interfaces from
+ *                        nested packages (default: true.)
+ */
+void UMLPackage::appendInterfaces( UMLClassifierList& interfaces,
+                                   bool includeNested /* = true */)
+{
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
+        UMLObject *o = oit.next();
+        ObjectType ot = o->baseType();
+        if (ot == ot_Interface) {
+            UMLClassifier *c = static_cast<UMLClassifier*>(o);
+            interfaces.append(c);
+        } else if (includeNested && (ot == ot_Package || ot == ot_Folder)) {
+            UMLPackage *inner = static_cast<UMLPackage *>(o);
+            inner->appendInterfaces(interfaces);
+        }
+    }
+}
+
 /**
  * Resolve types. Required when dealing with foreign XMI files.
  * Needs to be called after all UML objects are loaded from file.
@@ -389,9 +418,8 @@ void UMLPackage::appendClassesAndInterfaces(UMLClassifierList& classifiers,
 bool UMLPackage::resolveRef()
 {
     bool overallSuccess = UMLCanvasObject::resolveRef();
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         UMLObject *obj = oit.next();
-        uIgnoreZeroPointer(obj);
         if (! obj->resolveRef()) {
             UMLObject::ObjectType ot = obj->baseType();
             if (ot != UMLObject::ot_Package && ot != UMLObject::ot_Folder)
@@ -407,17 +435,16 @@ bool UMLPackage::resolveRef()
  */
 void UMLPackage::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
-    QDomElement packageElement = UMLObject::save(QLatin1String("UML:Package"), qDoc);
-    QDomElement ownedElement = qDoc.createElement(QLatin1String("UML:Namespace.ownedElement"));
+    QDomElement packageElement = UMLObject::save("UML:Package", qDoc);
+    QDomElement ownedElement = qDoc.createElement("UML:Namespace.ownedElement");
     UMLObject *obj = NULL;
     // save classifiers etc.
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         obj = oit.next();
-        uIgnoreZeroPointer(obj);
         obj->saveToXMI (qDoc, ownedElement);
     }
     // save associations
-    for (UMLObjectListIt ait(m_List); ait.hasNext();) {
+    for (UMLObjectListIt ait(m_List); ait.hasNext(); ) {
         obj = ait.next();
         obj->saveToXMI (qDoc, ownedElement);
     }
@@ -440,21 +467,17 @@ bool UMLPackage::load(QDomElement& element)
         QString type = tempElement.tagName();
         if (Model_Utils::isCommonXMIAttribute(type))
             continue;
-        if (UMLDoc::tagEq(type, QLatin1String("Namespace.ownedElement")) ||
-                UMLDoc::tagEq(type, QLatin1String("Element.ownedElement")) ||  // Embarcadero's Describe
-                UMLDoc::tagEq(type, QLatin1String("Namespace.contents"))) {
+        if (UMLDoc::tagEq(type, "Namespace.ownedElement") ||
+                UMLDoc::tagEq(type, "Namespace.contents")) {
             //CHECK: Umbrello currently assumes that nested elements
             // are ownedElements anyway.
             // Therefore these tags are not further interpreted.
             if (! load(tempElement))
                 return false;
             continue;
-        } else if (UMLDoc::tagEq(type, QLatin1String("packagedElement")) ||
-                   UMLDoc::tagEq(type, QLatin1String("ownedElement"))) {
-            type = tempElement.attribute(QLatin1String("xmi:type"));
         }
         UMLObject *pObject = Object_Factory::makeObjectFromXMI(type);
-        if(!pObject) {
+        if( !pObject ) {
             uWarning() << "Unknown type of umlobject to create: " << type;
             continue;
         }
@@ -467,3 +490,4 @@ bool UMLPackage::load(QDomElement& element)
     return true;
 }
 
+#include "package.moc"
