@@ -358,17 +358,6 @@ void UMLObject::emitModified()
         emit modified();
 }
 
-/**
- * Sets the documentation for the object.
- *
- * @param d The documentation for the object.
- */
-void UMLObject::setDoc(const QString &d)
-{
-    m_Doc = d;
-    //emit modified();  No, this is done centrally at DocWindow::updateDocumentation()
-}
-
 /**
  * Returns the type of the object.
  *
@@ -417,6 +406,27 @@ QString UMLObject::doc() const
     return m_Doc;
 }
 
+/**
+ * Returns state of documentation for the object.
+ *
+ * @return false if documentation is empty
+ */
+bool UMLObject::hasDoc() const
+{
+    return !m_Doc.isEmpty();
+}
+
+/**
+ * Sets the documentation for the object.
+ *
+ * @param d The documentation for the object.
+ */
+void UMLObject::setDoc(const QString &d)
+{
+    m_Doc = d;
+    //emit modified();  No, this is done centrally at DocWindow::updateDocumentation()
+}
+
 /**
  * Returns the visibility of the object.
  *
