@@ -19,7 +19,6 @@
 #include "umlscene.h"
 #include "widgetbase.h"
 
-class ListPopupMenu;
 class ClassifierWidget;
 class UMLDoc;
 class UMLScene;
@@ -205,9 +204,11 @@ public:
 
     void cleanup();
 
-public slots:
-    void slotMenuSelection(QAction* action);
-    void slotRemovePopupMenu();
+    bool isPointAddable();
+    bool isPointRemovable();
+
+public Q_SLOTS:
+    virtual void slotMenuSelection(QAction* action);
     void slotClearAllSelected();
     void slotClassifierListItemRemoved(UMLClassifierListItem* obj);
     void slotAttributeChanged();
@@ -215,7 +216,7 @@ public slots:
     void syncToModel();
 
 protected:
-    ListPopupMenu* setupPopupMenu(ListPopupMenu *menu=0, const QPointF &p=QPointF());
+    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
 
 private:
     void init();
@@ -297,6 +298,8 @@ private:
     void setChangeWidget(const QString &strChangeWidget, Uml::RoleType::Enum role);
 
     void checkPoints(const UMLScenePoint &p);
+    bool checkAddPoint(const UMLScenePoint &scenePos);
+    bool checkRemovePoint(const UMLScenePoint &scenePos);
 
     bool linePathStartsAt(const UMLWidget* widget);
 
@@ -317,7 +320,6 @@ private:
      */
     uint                m_unNameLineSegment;
     UMLDoc              *m_umldoc;  ///< just a shorthand for UMLApp::app()->getDocument()
-    ListPopupMenu       *m_pMenu;
     bool                m_selected;
     int                 m_nMovingPoint;
 
@@ -340,6 +342,7 @@ private:
     Uml::AssociationType::Enum m_associationType;  ///< is only used if m_pObject is not set
     WidgetRole  m_role[2];
     FloatingTextWidget* m_nameWidget;  ///< displays the name of this association
+    QPointF m_eventScenePos;           ///< holds scene pos of contextMenuEvent()
 
 };
 
